@@ -3,7 +3,7 @@ import sys
 from enum import Enum
 from subprocess import call, DEVNULL
 
-from urh import constants
+from urh import settings
 from urh.util.Logger import logger
 
 
@@ -18,8 +18,7 @@ class BackendContainer(object):
     def __init__(self, name, avail_backends: set, supports_rx: bool, supports_tx: bool):
         self.name = name
         self.avail_backends = avail_backends
-        settings = constants.SETTINGS
-        self.selected_backend = Backends[settings.value(name + "_selected_backend", "none")]
+        self.selected_backend = Backends[settings.read(name + "_selected_backend", "none")]
         if self.selected_backend not in self.avail_backends:
             self.selected_backend = Backends.none
 
@@ -29,7 +28,7 @@ class BackendContainer(object):
             elif Backends.grc in self.avail_backends:
                 self.selected_backend = Backends.grc
 
-        self.is_enabled = settings.value(name + "_is_enabled", True, bool)
+        self.is_enabled = settings.read(name + "_is_enabled", True, bool)
         self.__supports_rx = supports_rx
         self.__supports_tx = supports_tx
         if len(self.avail_backends) == 0:
@@ -63,8 +62,7 @@ class BackendContainer(object):
         self.write_settings()
 
     def write_settings(self):
-        settings = constants.SETTINGS
-        settings.setValue(self.name + "_is_enabled", self.is_enabled)
+        settings.write(self.name + "_is_enabled", self.is_enabled)
 
         if self.selected_backend == Backends.grc and len(self.avail_backends) == 1:
             # if GNU Radio is the only backend available we do not save it to ini,
@@ -72,7 +70,7 @@ class BackendContainer(object):
             # see: https://github.com/jopohl/urh/issues/270
             pass
         else:
-            settings.setValue(self.name + "_selected_backend", self.selected_backend.name)
+            settings.write(self.name + "_selected_backend", self.selected_backend.name)
 
 
 class BackendHandler(object):
@@ -83,28 +81,16 @@ class BackendHandler(object):
     3) Manage the selection of devices backend
 
     """
-    DEVICE_NAMES = ("AirSpy R2", "AirSpy Mini", "BladeRF", "FUNcube", "HackRF",
+    DEVICE_NAMES = ("AirSpy R2", "AirSpy Mini", "BladeRF", "FUNcube", "HackRF", "Rad1o",
                     "LimeSDR", "PlutoSDR", "RTL-SDR", "RTL-TCP", "SDRPlay", "SoundCard", "USRP")
 
     def __init__(self):
 
-        python2_exe = constants.SETTINGS.value('python2_exe', '')
-        if not python2_exe:
-            self.__python2_exe = self.__get_python2_interpreter()
-            constants.SETTINGS.setValue("python2_exe", self.__python2_exe)
-        else:
-            self.__python2_exe = python2_exe
+        self.__gr_python_interpreter = settings.read('gr_python_interpreter', '')
+        if not self.__gr_python_interpreter:
+            self.__gr_python_interpreter = settings.read("python2_exe", '')  # legacy
 
-        constants.SETTINGS.setValue("python2_exe", self.__python2_exe)
-
-        self.gnuradio_install_dir = constants.SETTINGS.value('gnuradio_install_dir', "")
-        self.use_gnuradio_install_dir = constants.SETTINGS.value('use_gnuradio_install_dir', os.name == "nt", bool)
-
-        self.gnuradio_is_installed = constants.SETTINGS.value('gnuradio_is_installed', -1, int)
-        if self.gnuradio_is_installed == -1:
-            self.set_gnuradio_installed_status()
-        else:
-            self.gnuradio_is_installed = bool(self.gnuradio_is_installed)
+        self.set_gnuradio_installed_status()
 
         if not hasattr(sys, 'frozen'):
             self.path = os.path.dirname(os.path.realpath(__file__))
@@ -117,14 +103,15 @@ class BackendHandler(object):
         self.get_backends()
 
     @property
-    def python2_exe(self):
-        return self.__python2_exe
+    def gr_python_interpreter(self):
+        return self.__gr_python_interpreter
 
-    @python2_exe.setter
-    def python2_exe(self, value):
-        if value != self.__python2_exe:
-            self.__python2_exe = value
-            constants.SETTINGS.setValue("python2_exe", value)
+    @gr_python_interpreter.setter
+    def gr_python_interpreter(self, value):
+        if value != self.__gr_python_interpreter:
+            self.__gr_python_interpreter = value
+            self.set_gnuradio_installed_status(force=True)
+            settings.write("gr_python_interpreter", value)
 
     @property
     def num_native_backends(self):
@@ -217,28 +204,25 @@ class BackendHandler(object):
         except ImportError:
             return False
 
-    def set_gnuradio_installed_status(self):
-        if self.use_gnuradio_install_dir:
-            # We are probably on windows with a bundled gnuradio installation
-            bin_dir = os.path.join(self.gnuradio_install_dir, "bin")
-            site_packages_dir = os.path.join(self.gnuradio_install_dir, "lib", "site-packages")
-            if all(os.path.isdir(dir) for dir in [self.gnuradio_install_dir, bin_dir, site_packages_dir]):
-                self.gnuradio_is_installed = True
-            else:
+    def __check_gr_python_interpreter(self, interpreter):
+        # Use shell=True to prevent console window popping up on windows
+        return call('"{0}" -c "import gnuradio"'.format(interpreter), shell=True, stderr=DEVNULL) == 0
+
+    def set_gnuradio_installed_status(self, force=False):
+        current_setting = settings.read('gnuradio_is_installed', -1, int)
+        if not force and current_setting != -1:
+            self.gnuradio_is_installed = bool(current_setting)
+            return
+
+        if os.path.isfile(self.gr_python_interpreter) and os.access(self.gr_python_interpreter, os.X_OK):
+            try:
+                self.gnuradio_is_installed = self.__check_gr_python_interpreter(self.gr_python_interpreter)
+            except OSError:
                 self.gnuradio_is_installed = False
         else:
-            if os.path.isfile(self.python2_exe) and os.access(self.python2_exe, os.X_OK):
-                try:
-                    # Use shell=True to prevent console window popping up on windows
-                    self.gnuradio_is_installed = call('"{0}" -c "import gnuradio"'.format(self.python2_exe),
-                                                      shell=True, stderr=DEVNULL) == 0
-                except OSError as e:
-                    logger.error("Could not determine GNU Radio install status. Assuming true. Error: " + str(e))
-                    self.gnuradio_is_installed = True
-            else:
-                self.gnuradio_is_installed = False
+            self.gnuradio_is_installed = False
 
-        constants.SETTINGS.setValue("gnuradio_is_installed", int(self.gnuradio_is_installed))
+        settings.write("gnuradio_is_installed", int(self.gnuradio_is_installed))
 
     def __device_has_gr_scripts(self, devname: str):
         if not hasattr(sys, "frozen"):
@@ -274,6 +258,10 @@ class BackendHandler(object):
             supports_rx, supports_tx = True, True
             backends.add(Backends.native)
 
+        if devname.lower() == "rad1o" and self.__hackrf_native_enabled:
+            supports_rx, supports_tx = True, True
+            backends.add(Backends.native)
+
         if devname.lower() == "usrp" and self.__usrp_native_enabled:
             supports_rx, supports_tx = True, True
             backends.add(Backends.native)
@@ -327,14 +315,3 @@ class BackendHandler(object):
             return result + "OK"
         except Exception as e:
             return result + str(e)
-
-    def __get_python2_interpreter(self):
-        paths = os.get_exec_path()
-
-        for p in paths:
-            for prog in ["python2", "python2.exe"]:
-                attempt = os.path.join(p, prog)
-                if os.path.isfile(attempt):
-                    return attempt
-
-        return ""
